pub struct RuleHandler {
pub config: Option<Option<Value>>,
pub handler: Option<String>,
}Fields
config: Option<Option<Value>>Config contains the configuration for the handler. Please read the user guide for a complete list of each handler’s available settings.
handler: Option<String>Handler identifies the implementation which will be used to handle this specific request. Please read the user guide for a complete list of available handlers.
Implementations
Sourceimpl RuleHandler
impl RuleHandler
pub fn new() -> RuleHandler